@@ -69,7 +69,10 @@ def channel_send(logger, channel, message):
 
 def syncify_async_function(async_func):
     loop = asyncio.get_event_loop()
-
+    if loop is None:
+        print("loop is none")
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
     def sync_func(*args, **kwargs):
         if not loop.is_running():
             loop.run_until_complete(asyncio.sleep(0))
@@ -233,7 +236,6 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
 
-
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
                     syncify_async_function(self.peerConnections[id].setRemoteDescription(answer))
